==> kubernetes-model-core-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/LifecycleFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LifecycleFluent<A extends LifecycleFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildPostStart instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHandler getPostStart();
  public LifecycleHandler buildPostStart();
  public A withPostStart(LifecycleHandler postStart);
  public Boolean hasPostStart();
  public LifecycleFluent.PostStartNested<A> withNewPostStart();
  public LifecycleFluent.PostStartNested<A> withNewPostStartLike(LifecycleHandler item);
  public LifecycleFluent.PostStartNested<A> editPostStart();
  public LifecycleFluent.PostStartNested<A> editOrNewPostStart();
  public LifecycleFluent.PostStartNested<A> editOrNewPostStartLike(LifecycleHandler item);
  
  /**
   * This method has been deprecated, please use method buildPreStop instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHandler getPreStop();
  public LifecycleHandler buildPreStop();
  public A withPreStop(LifecycleHandler preStop);
  public Boolean hasPreStop();
  public LifecycleFluent.PreStopNested<A> withNewPreStop();
  public LifecycleFluent.PreStopNested<A> withNewPreStopLike(LifecycleHandler item);
  public LifecycleFluent.PreStopNested<A> editPreStop();
  public LifecycleFluent.PreStopNested<A> editOrNewPreStop();
  public LifecycleFluent.PreStopNested<A> editOrNewPreStopLike(LifecycleHandler item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PostStartNested<N> extends Nested<N>,LifecycleHandlerFluent<LifecycleFluent.PostStartNested<N>>{
    public N and();
    public N endPostStart();
    
  }
  public interface PreStopNested<N> extends Nested<N>,LifecycleHandlerFluent<LifecycleFluent.PreStopNested<N>>{
    public N and();
    public N endPreStop();
    
  }
  
}

==> kubernetes-model-core-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/LifecycleFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LifecycleFluent<A extends LifecycleFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildPostStart instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHandler getPostStart();
  public LifecycleHandler buildPostStart();
  public A withPostStart(LifecycleHandler postStart);
  public Boolean hasPostStart();
  public LifecycleFluent.PostStartNested<A> withNewPostStart();
  public LifecycleFluent.PostStartNested<A> withNewPostStartLike(LifecycleHandler item);
  public LifecycleFluent.PostStartNested<A> editPostStart();
  public LifecycleFluent.PostStartNested<A> editOrNewPostStart();
  public LifecycleFluent.PostStartNested<A> editOrNewPostStartLike(LifecycleHandler item);
  
  /**
   * This method has been deprecated, please use method buildPreStop instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHandler getPreStop();
  public LifecycleHandler buildPreStop();
  public A withPreStop(LifecycleHandler preStop);
  public Boolean hasPreStop();
  public LifecycleFluent.PreStopNested<A> withNewPreStop();
  public LifecycleFluent.PreStopNested<A> withNewPreStopLike(LifecycleHandler item);
  public LifecycleFluent.PreStopNested<A> editPreStop();
  public LifecycleFluent.PreStopNested<A> editOrNewPreStop();
  public LifecycleFluent.PreStopNested<A> editOrNewPreStopLike(LifecycleHandler item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PostStartNested<N> extends Nested<N>,LifecycleHandlerFluent<LifecycleFluent.PostStartNested<N>>{
    public N and();
    public N endPostStart();
    
  }
  public interface PreStopNested<N> extends Nested<N>,LifecycleHandlerFluent<LifecycleFluent.PreStopNested<N>>{
    public N and();
    public N endPreStop();
    
  }
  
}
